@@ -1,5 +1,7 @@
 # coding: utf-8
+import pymongo
 from pymongo import MongoClient
+import re
 
 """
 use admin
@@ -15,6 +17,9 @@ db.createUser(
 删除用户：
 use XXXX
 db.dropUser('XXXXX')
+
+修改多个文档的某一个字段：
+db.XXX.update({"DDD":{"$exists":true}},{$set:{"DDD":W}},{multi:true})
 """
 
 
@@ -22,6 +27,8 @@ class BaseMongoDB(object):
     """
     数据库基类
     """
+    asc = pymongo.ASCENDING
+    desc = pymongo.DESCENDING
 
     def __init__(self, name, host, port, db, **kwargs):
         self.name = name
@@ -41,11 +48,11 @@ class BaseMongoDB(object):
         self.name = name
         self.task = self.db[self.name]
 
-    def get_one(self, key: dict):
-        return self.task.find_one(key)
+    def get_one(self, key: dict, **kwargs):
+        return self.task.find_one(key, **kwargs)
 
-    def find(self, key: dict):
-        return self.task.find(key)
+    def find(self, key: dict, **kwargs):
+        return self.task.find(key, **kwargs)
 
     def get_all(self):
         return [data for data in self.task.get()]
@@ -79,6 +86,10 @@ class BaseMongoDB(object):
         """
         return self.task.update_one(key, {"$pull": obj}, upsert=True).raw_result
 
+    def pull_many(self, key: dict, obj: dict):
+        """从array删除满足条件的所有数据"""
+        return self.task.update_many(key, {"$pull": obj}, upsert=True).raw_result
+
     def pop_one(self, key: dict, where: str):
         """
         从array弹出最早的一条数据
@@ -99,6 +110,23 @@ class BaseMongoDB(object):
         """
         return self.task.update_one(key, {"$inc": {obj_key: step}})
 
+    @staticmethod
+    def sql_condition(sql):
+        condition = {}
+        modifier = {'<=': '$lte', '>=': '$gte', '=': '$eq', '>': '$gt', '<': '$lt', 'like': '$regex'}
+        split_symbol = f"\s({'|'.join([i for i in modifier.keys()])})\s"
+        # 先对and处理
+        sql = sql.split(' and ')
+        sql = [re.split(split_symbol, i.strip(), maxsplit=1) for i in sql]
+        for s in sql:
+            s = [i.strip() for i in s]
+            s[2] = int(s[2]) if re.sub('\d+', '', s[2]) == '' else s[2]
+            if s[1] == 'like':
+                if s[2].startswith('%') and s[2].endswith('%'):
+                    s[2] = s[2].strip('%')
+            condition[s[0]] = {modifier[s[1]]: s[2]}
+        return condition
+
 
 """
 由于mongodb中key值不能存在'.'，故对于字典的key值全部进行转换
