@@ -13,7 +13,7 @@ class Mysql(object):
     """
 
     def __init__(self, db, host, port, user, pwd):
-        self.db = pymysql.connect(host=host, port=port, user=user, password=pwd)
+        self.db = pymysql.connect(host=host, port=port, user=str(user), password=str(pwd))
         self.cursor = self.db.cursor()
         self.current_db = db
 
